.. _apiref:

===============
 API Reference
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    celery
    celery.app
    celery.app.task
    celery.app.amqp
    celery.app.defaults
    celery.app.control
    celery.app.registry
    celery.app.builtins
    celery.app.log
    celery.app.utils
    celery.bootsteps
    celery.result
    celery.task.http
    celery.schedules
    celery.signals
    celery.security
    celery.utils.debug
    celery.utils.mail
    celery.exceptions
    celery.loaders
    celery.loaders.app
    celery.loaders.default
    celery.loaders.base
    celery.states
    celery.contrib.abortable
    celery.contrib.batches
    celery.contrib.migrate
    celery.contrib.sphinx
    celery.contrib.rdb
    celery.contrib.methods
    celery.events
    celery.events.state
    celery.beat
    celery.apps.worker
    celery.apps.beat
    celery.worker
    celery.worker.consumer
    celery.worker.job
    celery.worker.state
    celery.worker.strategy
    celery.bin.base
    celery.bin.celery
    celery.bin.worker
    celery.bin.beat
    celery.bin.events
    celery.bin.amqp
    celery.bin.multi
    celery.bin.graph
